@@ -633,6 +633,16 @@ class GtkFrontend(Frontend):
         if response == Gtk.ResponseType.OK:
             filename = chooser.get_filename()
             chooser.destroy()
+            treeview = self.source_treeview
+            model = treeview.get_model()
+            iterator = model.get_iter_first()
+            while iterator is not None:
+                if model.get_value(iterator, 0) == filename:
+                    path = model.get_path(iterator)
+                    treeview.set_cursor(path, None, False)
+                    treeview.scroll_to_cell(path)
+                    return
+                iterator = model.iter_next(iterator)
             self.backend.add_image(filename)
         elif response == Gtk.ResponseType.CANCEL:
             chooser.destroy()
@@ -815,5 +825,6 @@ def _append_to_list_and_select(treeview, new_row, force_selection):
     new_iter = model.append(new_row)
     if force_selection or (treeview.get_selection().get_selected()[1] is None):
         treeview.set_cursor(model.get_path(new_iter), None, False)
+        treeview.scroll_to_cell(model.get_path(new_iter))
 
 # vim: set ai et sts=4 tabstop=4 sw=4:
